"""Project metadata.
"""

__all__ = [
    '__title__',
    '__summary__',
    '__url__',
    '__version__',
    '__author__',
    '__email__',
    '__license__',
]

__title__ = 'alchy'
__summary__ = ('A SQLAlchemy extension for its declarative ORM that provides '
               'enhancements for model classes, queries, and sessions.')
__url__ = 'https://github.com/dgilland/alchy'
__version__ = '1.2.0'
__author__ = 'Derrick Gilland'
__email__ = 'dgilland@gmail.com'
__license__ = 'MIT License'
